import Vue from "vue";
import store from '@/store'
import axios from 'axios'
import { Message } from 'element-ui'
import util from '@/libs/util'

// 创建一个错误
function errorCreat (msg) {
  const err = new Error(msg)
  errorLog(err)
  throw err
}

// 记录和显示错误
function errorLog (err) {
  // 添加到日志
  store.dispatch('d2admin/log/add', {
    type: 'error',
    err,
    info: '数据请求异常'
  })
  // 打印到控制台
  if (process.env.NODE_ENV === 'development') {
    util.log.danger('>>>>>> Error >>>>>>')
    console.log(err)
  }
  // 显示提示
  Message({
    message: err.message,
    type: 'error',
    duration: 5 * 1000
  })
}

// 创建一个 axios 实例
const service = axios.create({
  baseURL: process.env.VUE_APP_API,
  timeout: 5000 // 请求超时时间
})

// 初始化配置
service.defaults.withCredentials = true; // 允许跨域携带cookie
service.defaults.timeout = 40000; // 超时时间
service.defaults.headers.common["X-Requested-With"] = "XMLHttpRequest"; // 标识这是一个 ajax 请求 

Vue.prototype.$http = service;

Vue.prototype.$http.headers = {
  "FORM": {
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
    }
  },
  "JSON":{
    headers: {
      "Accept": "application/json",
      "Content-Type": "application/json; charset=UTF-8"
    }
  }
};

// 请求拦截器
service.interceptors.request.use(
  config => {
    // 在请求发送之前做一些处理
    if (!(/^https:\/\/|http:\/\//.test(config.url))) {
      const token = util.cookies.get('token')
      if (token && token !== 'undefined') {
        // 让每个请求携带token-- ['X-Token']为自定义key 请根据实际情况自行修改
        // config.headers['X-Token'] = token
      }
    }

    // 打包配置
     
    config.url = "/ses-enrol-v1/" + config.url;
    // 处理用户登陆id
    let uerStr = localStorage.getItem("user");
    if(uerStr){
      let user = JSON.parse(uerStr);
      if(user && config.url.indexOf('std_id=') == -1){
        if(config.url.indexOf('?') != -1){
          config.url = config.url + `&std_id=${user.id}`;
        }else{
          config.url = config.url + `?std_id=${user.id}`;
        }
        
      }
    }
      
    

    return config
  },
  error => {
    // 发送失败
    console.log(error)
    Promise.reject(error)
  }
)

// 响应拦截器
service.interceptors.response.use(
  response => {
    // dataAxios 是 axios 返回数据中的 data
    const dataAxios = response
    if(dataAxios.data.errorCode && dataAxios.data.errorCode == 246){
      // this.$alert("检测到考生登录异常,请不要在同一个浏览器登录多个用户,请务必退出后重新登录!", "信息提示", {});
      alert("检测到考生登录异常,请不要在同一个浏览器登录多个用户,请退出后重新登录!");
      util.cookies.remove('token')
      util.cookies.remove('uuid')
      window.location.href='login/login.html'
      return;
    }
    //session 失效跳转重新登录
    if(!dataAxios.data.login &&  dataAxios.config.responseType != "blob"){
      
      util.cookies.remove('token')
      util.cookies.remove('uuid')
      window.location.href='login/login.html'
      return;
    }
    // const dataAxios = response.data
    // 这个状态码是和后端约定的
    const { code } = dataAxios.data
    // 根据 code 进行判断
    if (code === undefined) {
      // 如果没有 code 代表这不是项目后端开发的接口 比如可能是 D2Admin 请求最新版本
      return dataAxios
    } else {
      // 有 code 代表这是一个后端接口 可以进行进一步的判断
      switch (code) {
        case 0:
          // [ 示例 ] code === 0 代表没有错误
          return dataAxios
        case 'xxx':
          // [ 示例 ] 其它和后台约定的 code
          errorCreat(`[ code: xxx ] ${dataAxios.data.msg}: ${response.config.url}`)
          break
        default:
          // 不是正确的 code
          errorCreat(`${dataAxios.data.msg}: ${response.config.url}`)
          break
      }
    }
  },
  error => {
    if (error && error.response) {
      switch (error.response.status) {
        case 400: error.message = '请求错误'; break
        case 401: error.message = '未授权，请登录'; break
        case 403: error.message = '拒绝访问'; break
        case 404: error.message = `请求地址出错: ${error.response.config.url}`; break
        case 408: error.message = '请求超时'; break
        case 500: error.message = '服务器内部错误'; break
        case 501: error.message = '服务未实现'; break
        case 502: error.message = '网关错误'; break
        case 503: error.message = '服务不可用'; break
        case 504: error.message = '网关超时'; break
        case 505: error.message = 'HTTP版本不受支持'; break
        default: break
      }
    }
    errorLog(error)
    return Promise.reject(error)
  }
)

export default service
